package com.qmth.teachcloud.report.api;


import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import com.qmth.teachcloud.report.business.entity.TAExamCourse;
import com.qmth.teachcloud.report.business.entity.TAExamCourseTeacher;
import com.qmth.teachcloud.report.business.entity.TAExamTotal;
import com.qmth.teachcloud.report.business.service.TAExamCourseService;
import com.qmth.teachcloud.report.business.service.TAExamCourseTeacherService;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;

import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 考试课程维度分析表 前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2021-06-01
 */
@Api(tags = "教研分析数据驾驶舱模块Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.reportSchool}/course")
public class TAExamCourseController {

    @Autowired
    private TAExamCourseService taExamCourseService;

    @Autowired
    private TAExamCourseTeacherService taExamCourseTeacherService;

    @ApiOperation(value = "全校考试总览-全校考试概况")
    @RequestMapping(value = "/get_overview", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "全校考试总览-全校考试概况", response = TAExamCourse.class)})
    public Result getOverview(
            @ApiParam(value = "学期", required = true) @RequestParam String semester,
            @ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
            @ApiParam(value = "课程代码", required = true) @RequestParam String courseCode) {
        return ResultUtil.ok(taExamCourseService.getOverview(semester, examId, courseCode));
    }

    @ApiOperation(value = "全校课程考试分析-教师各课堂成绩排名")
    @RequestMapping(value = "/list_teacher_class_rank", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "全校课程考试分析-教师各课堂成绩排名", response = TAExamCourseTeacher.class)})
    public Result listTeacherClassRank(
            @ApiParam(value = "学期", required = true) @RequestParam String semester,
            @ApiParam(value = "考试ID", required = true) @RequestParam Long examId,
            @ApiParam(value = "课程代码", required = true) @RequestParam String courseCode,
            @ApiParam(value = "分页页码", required = true) @RequestParam Integer pageNumber,
            @ApiParam(value = "分页数量", required = true) @RequestParam Integer pageSize) {
        return ResultUtil.ok(taExamCourseTeacherService.listTeacherClassRank(semester, examId, courseCode, pageNumber, pageSize));
    }

}
